# MhcVizPipe (MVP)
A reporting pipeline for visualization of immunopeptidomics MS data.

## Installation

MVP requires separate installations of NetMHCpan (version 4.0 or 4.1), NetMHCIIpan4.0 and GibbsCluster2.0.
If you do not have these programs already, please download them from DTU Health Tech at
https://services.healthtech.dtu.dk/software.php. The programs come with detailed installation instructions, but
if you need help please see our wiki (not yet done) or even
[open an issue on our GitHub page and we can help!](https://github.com/kevinkovalchik/MhcVizPipe/issues)

You have a few options for installing MVP itself, installing from PyPI using pip, cloning this repository
and installing from the source code, or by downloading a pre-built standalone
version of the Python code. If you said "Huh?" when you saw the words PyPI, pip and cloning, you probably want to
start with the pre-built version. This can be downloaded here (link to come soon).